@@ -7,6 +7,7 @@ import datetime
 from gettext import gettext as _
 import gi
 import logging
+import os
 import sys
 import threading
 
@@ -82,6 +83,7 @@ CREDITS = dict(
         'twlvnn (Bulgarian)',
         'Roger VC (Catalan)',
         'Lukáš Linhart (Czech)',
+        'Jakub Soukup (Czech)',
         'Dingzhong Chen (Simplified Chinese)',
         'Eric-Song-Nop (Simplified Chinese)',
         'Inaha (Simplified Chinese)',
@@ -163,6 +165,7 @@ class Application(Adw.Application):
 
         self.window = None
 
+        self.add_main_option_entries([])
         self.set_resource_base_path('/info/febvre/Komikku')
         GLib.set_application_name('Komikku')
 
@@ -482,7 +485,7 @@ class ApplicationWindow(Adw.ApplicationWindow):
 
         set_color_scheme()
 
-    def install_servers_modules(self, reinit=False):
+    def install_servers_modules(self):
         def run():
             res, status = install_servers_modules_from_repo(self.application.version)
             GLib.idle_add(complete, res, status)
@@ -490,8 +493,7 @@ class ApplicationWindow(Adw.ApplicationWindow):
         def complete(res, status):
             if res is True:
                 if status == 'updated':
-                    self.add_notification(_('Servers modules have been updated'))
-                self.reinit_servers_modules()
+                    self.restart(_('Servers modules have been updated'))
 
             elif res is False:
                 if status == 'unchanged':
@@ -505,13 +507,9 @@ class ApplicationWindow(Adw.ApplicationWindow):
                         cancel_label=_('Close'),
                     )
                     self.application.logger.info('Failed to updates servers modules: incompatible app version')
-                if reinit:
-                    self.reinit_servers_modules()
 
             else:
                 self.application.logger.info('Failed to update servers modules')
-                if reinit:
-                    self.reinit_servers_modules()
 
         thread = threading.Thread(target=run)
         thread.daemon = True
@@ -537,15 +535,26 @@ available in your region/language."""))
         # Override release notes
         dialog.set_release_notes("""
             <ul>
-                <li>[Library] Added ability to update with &lt;Ctrl+r&gt; shortcut</li>
-                <li>[Card] Info: Improved display of Genres using badges</li>
-                <li>[Servers] Added MangaBin (EN)</li>
-                <li>[Servers] Added Vortex Scans For Free (EN)</li>
-                <li>[Servers] Flame Comics (EN): Update</li>
-                <li>[Servers] Manhuaus (EN): Update</li>
-                <li>[Servers] Perf Scan (FR): Update</li>
-                <li>[Servers] Remanga (RU): Update</li>
-                <li>[L10n] Added Hungarian translation</li>
+                <li>[Servers] ريبر العربي (AR): Disabled</li>
+                <li>[Servers] 3asq (AR): Disabled</li>
+                <li>[Servers] Dango Scan (pt_BR): Update</li>
+                <li>[Servers] DB New Hope (EN/ES/FR): Update</li>
+                <li>[Servers] Dynasty Reader (EN): Update</li>
+                <li>[Servers] EZmanga (EN): Ignored chapters with price</li>
+                <li>[Servers] Mangago (EN): Update</li>
+                <li>[Servers] Mangaowl (EN): Update</li>
+                <li>[Servers] MangaReader (EN): Update</li>
+                <li>[Servers] MangaWorld (IT): Update</li>
+                <li>[Servers] Manhwa Hentai (EN): Disabled</li>
+                <li>[Servers] Mint Manga (RU): Disabled</li>
+                <li>[Servers] Nazarick Scan (pt_BR): Update</li>
+                <li>[Servers] PhenixScans (FR): Update</li>
+                <li>[Servers] Reaper Scans (EN): Update</li>
+                <li>[Servers] Terco Scans (EN): Update</li>
+                <li>[Servers] Tres Daos (ES): Update</li>
+                <li>[Servers] View Comics (EN): Update</li>
+                <li>[Servers] Xoxocomics (EN): Update</li>
+                <li>[L10n] Updated French and Russian translations</li>
             </ul>
             <p>Happy reading.</p>
         """)
@@ -669,20 +678,11 @@ available in your region/language."""))
 
         return Gdk.EVENT_STOP
 
-    def reinit_servers_modules(self):
-        """Used when origin of servers modules change"""
+    def restart(self, message):
+        def confirm_callback():
+            os.execv(sys.argv[0], sys.argv)
 
-        # Reload servers modules
-        init_servers_modules(Settings.get_default().external_servers_modules, reload_modules=True)
-
-        # Force re-instantiation of server instance variables
-        self.library.reinstantiate_servers()
-        self.card.reinstantiate_server()
-
-        for page in self.navigationview.get_navigation_stack():
-            if page.props.tag.startswith('explorer'):
-                self.explorer.reinstantiate_servers()
-                break
+        self.confirm(_('Restart?'), message, _('Restart'), confirm_callback)
 
     def save_window_size(self):
         if self.is_fullscreen():
