@@ -10,7 +10,7 @@ class Tecnoscan(MangaStream):
     name = 'Terco Scans (Tecno Scans)'
     lang = 'en'
 
-    base_url = 'https://tecnocomics.xyz'
+    base_url = 'https://tecnoxcomics.xyz'
     logo_url = base_url + '/wp-content/uploads/2024/11/cropped-LOGO-6-1-32x32.png'
 
     authors_selector = '.tsinfo .imptdt:-soup-contains("Artist") i, .tsinfo .imptdt:-soup-contains("Author") i'
