@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from komikku.servers.multi.manga_stream import MangaStream
@@ -9,10 +9,12 @@ class Tresdaos(MangaStream):
     id = 'tresdaos'
     name = 'Tres Daos'
     lang = 'es'
+    has_cf = True
 
     date_format = None
 
     base_url = 'https://tresdaos.com'
+    manga_list_url = base_url + '/'
 
     authors_selector = '.tsinfo .imptdt:-soup-contains("Autor") i, .tsinfo .imptdt:-soup-contains("Artista") i'
     genres_selector = '.info-desc .mgen a'
